aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--MAINTAINERS23
-rw-r--r--gcc/ChangeLog7
-rw-r--r--gcc/df-core.c6
-rw-r--r--gcc/df-scan.c12
-rw-r--r--gcc/testsuite/ChangeLog10
5 files changed, 39 insertions, 19 deletions
diff --git a/MAINTAINERS b/MAINTAINERS
index 873677d..65014db 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -194,8 +194,6 @@ build machinery (*.in) Paolo Bonzini bonzini@gnu.org
build machinery (*.in) DJ Delorie dj@redhat.com
build machinery (*.in) Nathanael Nerode neroden@gcc.gnu.org
build machinery (*.in) Alexandre Oliva aoliva@redhat.com
-dataflow Paolo Bonzini bonzini@gnu.org
-dataflow Daniel Berlin dberlin@dberlin.org
docs co-maintainer Gerald Pfeifer gerald@pfeifer.com
docs co-maintainer Joseph Myers jsm@polyomino.org.uk
predict.def Jan Hubicka jh@suse.cz
@@ -226,7 +224,7 @@ auto-vectorizer Richard Guenther rguenther@suse.de
auto-vectorizer Zdenek Dvorak dvorakz@suse.cz
auto-vectorizer Dorit Nuzman dorit@il.ibm.com
-Note individuals who maintain parts of the compiler need approval to check
+Note that individuals who maintain parts of the compiler need approval to check
in changes outside of the parts of the compiler they maintain.
Non-Algorithmic Maintainers
@@ -236,10 +234,24 @@ loop optimizer Daniel Berlin dberlin@dberlin.org
middle-end Richard Guenther rguenther@suse.de
libcpp Tom Tromey tromey@redhat.com
-Note individuals who maintain parts of the compiler as non-algorithmic
-maintainer need approval to check in algorithmic changes or changes
+Note that individuals who maintain parts of the compiler as non-algorithmic
+maintainers need approval to check in algorithmic changes or changes
outside of the parts of the compiler they maintain.
+ Non-Autopoiesis Maintainers
+
+dataflow Daniel Berlin dberlin@dberlin.org
+dataflow Paolo Bonzini bonzini@gnu.org
+dataflow Seonbae Park seongbae.park@gmail.com
+dataflow Kenneth Zadeck zadeck@naturalbridge.com
+(FIXME: The fortran people need to be added here since they follow this rule)
+
+
+Note that individuals who maintain parts of the compiler as
+non-autopoiesis maintainers need approval changes outside of the parts
+of the compiler they maintain and also need approval for their own
+patches.
+
Write After Approval (last name alphabetical order)
Mark G. Adams mark.g.adams@sympatico.ca
@@ -358,6 +370,7 @@ Carlos O'Donell carlos@codesourcery.com
Jeffrey D. Oldham oldham@codesourcery.com
Andrea Ornstein andrea.ornstein@st.com
Rainer Orth ro@TechFak.Uni-Bielefeld.DE
+Seonbae Park seongbae.park@gmail.com
Devang Patel dpatel@apple.com
Alexandre Petit-Bianco apbianco@redhat.com
Nicolas Pitre nico@cam.org
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 2b2134c..8b64afc 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,3 +1,10 @@
+2007-06-11 Kenneth Zadeck <zadeck@naturalbridge.com>
+
+ * df-scan.c (df_insn_delete, df_insn_rescan, df_insn_rescan_all,
+ df_process_deferred_rescans, df_notes_rescan): Fixed spelling of
+ word "deferred".
+ * df-core.c: Ditto.
+
2007-06-11 Daniel Berlin <dberlin@dberlin.org>
* Merge dataflow-branch into mainline (see ChangeLog.dataflow)
diff --git a/gcc/df-core.c b/gcc/df-core.c
index 56eb039..24c57e1 100644
--- a/gcc/df-core.c
+++ b/gcc/df-core.c
@@ -114,7 +114,7 @@ optimizations that reorder blocks invalidate the bitvector.
DF_ANALYZE causes all of the defined problems to be (re)solved. When
DF_ANALYZE is completes, the IN and OUT sets for each basic block
contain the computer information. The DF_*_BB_INFO macros can be used
-to access these bitvectors. All defered rescannings are down before
+to access these bitvectors. All deferred rescannings are down before
the transfer functions are recompited.
DF_DUMP can then be called to dump the information produce to some
@@ -126,7 +126,7 @@ can all be called separately as part of a larger dump function.
DF_FINISH_PASS causes df_remove_problem to be called on all of the
optional problems. It also causes any insns whose scanning has been
-defered to be rescanned as well as clears all of the changeable flags.
+deferred to be rescanned as well as clears all of the changeable flags.
Setting the pass manager TODO_df_finish flag causes this function to
be run. However, the pass manager will call df_finish_pass AFTER the
pass dumping has been done, so if you want to see the results of the
@@ -190,7 +190,7 @@ There are four ways of doing the incremental scanning:
To enable this mode, call df_set_flags (DF_DEFER_INSN_RESCAN).
(This mode can be cleared by calling df_clear_flags
- (DF_DEFER_INSN_RESCAN) but this does not cause the defered insns to
+ (DF_DEFER_INSN_RESCAN) but this does not cause the deferred insns to
be rescanned.
3) Total rescanning - In this mode the rescanning is disabled.
diff --git a/gcc/testsuite/ChangeLog b/gcc/testsuite/ChangeLog
index 4b014c8..547db8c 100644
--- a/gcc/testsuite/ChangeLog
+++ b/gcc/testsuite/ChangeLog
@@ -1,3 +1,8 @@
+2007-06-11 Paolo Bonzini <bonzini@gnu.org>
+
+ PR rtl-optimization/31025
+ * gfortran.dg/pr31025.f90: New.
+
2007-06-11 Uros Bizjak <ubizjak@gmail.com>
PR target/32280
@@ -2650,11 +2655,6 @@
PR tree-optimization/31041
* gcc.dg/vect/pr31041.c: New test.
-2007-03-16 Paolo Bonzini <bonzini@gnu.org>
-
- PR rtl-optimization/31025
- * gfortran.dg/pr31025.f90: New.
-
2007-03-16 Manuel Lopez-Ibanez <manu@gcc.gnu.org>
* g++.dg/warn/Wconversion-integer.C: New
diff --git a/gcc/df-scan.c b/gcc/df-scan.c
index 8c7cbf0..7b878fd 100644
--- a/gcc/df-scan.c
+++ b/gcc/df-scan.c
@@ -995,7 +995,7 @@ df_insn_delete (basic_block bb, unsigned int uid)
insn_info = DF_INSN_UID_SAFE_GET (uid);
/* The client has defered rescanning. */
if (df->changeable_flags & DF_DEFER_INSN_RESCAN)
{
if (insn_info)
@@ -1104,7 +1104,7 @@ df_insn_rescan (rtx insn)
insn_info = DF_INSN_UID_SAFE_GET (uid);
/* The client has defered rescanning. */
if (df->changeable_flags & DF_DEFER_INSN_RESCAN)
{
if (!insn_info)
@@ -1214,7 +1214,7 @@ df_insn_rescan_all (void)
}
/* Process all of the defered rescans or deletions. */
void
df_process_deferred_rescans (void)
@@ -1238,7 +1238,7 @@ df_process_deferred_rescans (void)
}
if (dump_file)
- fprintf (dump_file, "starting the processing of defered insns\n");
+ fprintf (dump_file, "starting the processing of deferred insns\n");
bitmap_copy (tmp, df->insns_to_delete);
EXECUTE_IF_SET_IN_BITMAP (tmp, 0, uid, bi)
@@ -1265,7 +1265,7 @@ df_process_deferred_rescans (void)
}
if (dump_file)
- fprintf (dump_file, "ending the processing of defered insns\n");
+ fprintf (dump_file, "ending the processing of deferred insns\n");
BITMAP_FREE (tmp);
bitmap_clear (df->insns_to_delete);
@@ -2009,7 +2009,7 @@ df_notes_rescan (rtx insn)
insn_info = DF_INSN_UID_SAFE_GET (INSN_UID(insn));
/* The client has defered rescanning. */
if (df->changeable_flags & DF_DEFER_INSN_RESCAN)
{
if (!insn_info)
@@ -995,7 +995,7 @@ df_insn_delete (basic_block bb, unsigned int uid)
insn_info = DF_INSN_UID_SAFE_GET (uid);
- /* The client has defered rescanning. */
+ /* The client has deferred rescanning. */
if (df->changeable_flags & DF_DEFER_INSN_RESCAN)
{
@@ -1104,7 +1104,7 @@ df_insn_rescan (rtx insn)
insn_info = DF_INSN_UID_SAFE_GET (uid);
- /* The client has defered rescanning. */
+ /* The client has deferred rescanning. */
if (df->changeable_flags & DF_DEFER_INSN_RESCAN)
{
@@ -1214,7 +1214,7 @@ df_insn_rescan_all (void)
}
-/* Process all of the defered rescans or deletions. */
+/* Process all of the deferred rescans or deletions. */
void
df_process_deferred_rescans (void)
@@ -2009,7 +2009,7 @@ df_notes_rescan (rtx insn)
insn_info = DF_INSN_UID_SAFE_GET (INSN_UID(insn));
- /* The client has defered rescanning. */
+ /* The client has deferred rescanning. */
if (df->changeable_flags & DF_DEFER_INSN_RESCAN)
{